@@ -5,16 +5,17 @@
 // Description:
 //
 //
-// Author: ian reinhart geiser <geiseri@yahoo.com>, (C) 2003
+// Copyright 2003 Ian Reinhart Geiser <geiseri@yahoo.com>
 //
-// Copyright: See COPYING file that comes with this distribution
+// GNU General Public License version 2
+// See COPYING file that comes with this distribution
 //
 //
 #ifndef STATIONDATABASE_H
 #define STATIONDATABASE_H
 
-#include <qmap.h>
-#include <qstring.h>
+#include <QtCore/QMap>
+#include <QtCore/QString>
 
 #include <klocale.h>
 #include <kstandarddirs.h>
@@ -25,12 +26,19 @@ This is the main database for mapping METAR codes to Station information.
 @author ian reinhart geiser
 */
 
-class StationInfo;
-
+class StationInfo
+{
+    public:
+        QString cityName;
+        QString country;
+        QString longitude;
+        QString latitude;
+        StationInfo () {}
+};
 class StationDatabase
 {
 public:
-    StationDatabase(const QString path = locate("data", "kweatherservice/stations.dat"));
+    StationDatabase(const QString &path = KStandardDirs::locate("data", "kweatherservice/stations.dat"));
     ~StationDatabase();
 
     QString stationNameFromID(const QString& id);
@@ -40,6 +48,8 @@ public:
     QString stationLatitudeFromID(const QString &stationID);
 
     QString stationCountryFromID( const QString &stationID);
+    
+    QString stationIDfromName( const QString &name );
 
 private:
     QMap<QString, StationInfo> theDB;
